﻿using System;
using System.Web.UI;
using System.Web.UI.HtmlControls;

namespace TechFest.SharePoint.JQuery.Utilities
{
    /// <summary>
    /// Helper Methods to register JavaScript and CSS.
    /// Partially derived from Dave Brace's posting:
    /// http://blogs.catalystss.com/blogs/dave_brace/archive/2009/03/12/registering-css-and-javascript-files-within-sharepoint-webparts.aspx
    /// </summary>
    public static class ClientSideHelpers
    {

        /// <summary>
        /// Checks if the specified JavaScript library is already registered and registers the script library
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the client script to register.</param>
        /// <param name="url">The URL of client-side script include to register.</param>
        public static void RegisterClientScriptInclude(Control control, string scriptKey, string scriptUrl)
        {
            ClientScriptManager csMgr = control.Page.ClientScript;

            // register library if not already registered
            if (!csMgr.IsClientScriptIncludeRegistered(scriptKey))
            {
                csMgr.RegisterClientScriptInclude(scriptKey, scriptUrl);
            }

        }


        /// <summary>
        /// Registers an unique instance of an inline script block
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the startup script to register.</param>
        /// <param name="script">The startup script literal to register.</param>
        public static void RegisterStartupScript(Control control, string key, string script)
        {
            ClientSideHelpers.RegisterStartupScript(control, key, script, true);
        }


        /// <summary>
        /// Registers an unique instance of an inline script block
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the startup script to register.</param>
        /// <param name="script">The startup script literal to register.</param>
        /// <param name="addScriptTags">A Boolean value indicating whether to add script tags.</param>
        public static void RegisterStartupScript(Control control, string key, string script, Boolean addScriptTags)
        {
            ClientScriptManager csMgr = control.Page.ClientScript;

            // create unique key for inline script block
            string initScriptKey = string.Format("{0}{1}", key, control.ClientID);

            // register inline script block
            if (!csMgr.IsClientScriptIncludeRegistered(control.GetType(), initScriptKey))
            {
                csMgr.RegisterStartupScript(control.GetType(), initScriptKey, script, addScriptTags);
            }
        }


        /// <summary>
        /// Checks if the specified CSS library is already registered and registers the CSS library
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the startup script to register.</param>
        /// <param name="url">The URL of style sheet include to register.</param>
        public static void RegisterCssLink(Control control, string key, string url)
        {
            ClientSideHelpers.RegisterCssLink(control, key, url, null, false);
        }


        /// <summary>
        /// Checks if the specified CSS library is already registered and registers the CSS library
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the startup script to register.</param>
        /// <param name="url">The URL of style sheet include to register.</param>
        /// <param name="media">Comma seperate list of media types affected by style sheet.</param>
        public static void RegisterCssLink(Control control, string key, string url, string media)
        {
            ClientSideHelpers.RegisterCssLink(control, key, url, media, false);
        }


        /// <summary>
        /// Checks if the specified CSS library is already registered and registers the CSS library
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the startup script to register.</param>
        /// <param name="url">The URL of style sheet include to register.</param>
        /// <param name="media">Comma seperate list of media types affected by style sheet.</param>
        /// <param name="alternate">A Boolean value indicating whether this is an alternate style sheet.</param>
        public static void RegisterCssLink(Control control, string key, string url, string media, Boolean alternate)
        {
            HtmlLink link = new HtmlLink();
            link.ID = key;
            link.Href = url;
            link.Attributes.Add("rel", string.Format("{0}{1}", (alternate ? "alternate " : ""), "stylesheet"));
            link.Attributes.Add("type", "text/css");
            link.Attributes.Add("media", media);

            // register library if not already registered
            if (control.Page.Header.FindControl(link.ID) == null)
            {
                control.Page.Header.Controls.Add(link);
            }
        }


        /// <summary>
        /// Registers an unique instance of an inline style block
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the startup script to register.</param>
        /// <param name="styles">The style block literal to register.</param>
        public static void RegisterStyleBlock(Control control, string key, string styles)
        {
            ClientSideHelpers.RegisterStyleBlock(control, key, styles, null);
        }


        /// <summary>
        /// Registers an unique instance of an inline style block
        /// </summary>
        /// <param name="webpart">The web part instance invoking this method.</param>
        /// <param name="key">The key of the startup script to register.</param>
        /// <param name="styles">The style block literal to register.</param>
        /// <param name="media">Comma seperate list of media types affected by style sheet.</param>
        public static void RegisterStyleBlock(Control control, string key, string styles, string media)
        {
            HtmlGenericControl style = new HtmlGenericControl("style");
            style.ID = key;
            style.Attributes.Add("type", "text/css");
            style.Attributes.Add("media", media);
            style.InnerText = styles;

            // register style block if not already registered
            if (control.Page.Header.FindControl(style.ID) == null)
            {
                control.Page.Header.Controls.Add(style);
            }
        }
    }
}
